from setuptools import setup

setup(
    name="smmap2",
    version="3.0.1",
    author="Sebastian Thiel",
    author_email="byronimo@gmail.com",
    description="A mirror package for smmap",
    long_description="This is a mirror package for `smmap <https://pypi.org/project/smmap/>`_. Consider installing it directly instead.",
    url="https://github.com/gitpython-developers/smmap",
    install_requires=["smmap>=3.0.1"],
)
